@@ -319,11 +319,11 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, int portCount, bool compactStyle,
     envelopeBox = new QGroupBox(tr("Envelope"), this);
     QVBoxLayout *envelopeBoxLayout = new QVBoxLayout;
     attackTime = new Slider(0, 20, 1, 1, 0, Qt::Horizontal,
-            tr("&Attack (s)"), envelopeBox);
+            tr("&Attack (beats)"), envelopeBox);
     connect(attackTime, SIGNAL(valueChanged(int)), this,
             SLOT(updateAttackTime(int)));
     releaseTime = new Slider(0, 20, 1, 1, 0, Qt::Horizontal,
-            tr("&Release (s)"), envelopeBox);
+            tr("&Release (beats)"), envelopeBox);
     connect(releaseTime, SIGNAL(valueChanged(int)), this,
             SLOT(updateReleaseTime(int)));
 
@@ -575,78 +575,6 @@ void ArpWidget::skipXmlElement(QXmlStreamReader& xml)
     }
 }
 
-void ArpWidget::readDataText(QTextStream& arpText)
-{
-    QString qs, qs2;
-    MidiCC midiCC;
-    qs = arpText.readLine();
-    qs2 = qs.section(' ', 0, 0);
-    chIn->setCurrentIndex(qs2.toInt());
-    qs2 = qs.section(' ', 1, 1);
-    repeatPatternThroughChord->setCurrentIndex(qs2.toInt());
-    qs = arpText.readLine();
-    qs2 = qs.section(' ', 0, 0);
-    indexIn[0]->setValue(qs2.toInt());
-    qs2 = qs.section(' ', 1, 1);
-    indexIn[1]->setValue(qs2.toInt());
-    qs = arpText.readLine();
-    qs2 = qs.section(' ', 0, 0);
-    rangeIn[0]->setValue(qs2.toInt());
-    qs2 = qs.section(' ', 1, 1);
-    rangeIn[1]->setValue(qs2.toInt());
-    qs = arpText.readLine();
-    qs2 = qs.section(' ', 0, 0);
-    channelOut->setCurrentIndex(qs2.toInt());
-    qs2 = qs.section(' ', 1, 1);
-    portOut->setCurrentIndex(qs2.toInt());
-    qs = arpText.readLine();
-    qs2 = qs.section(' ', 0, 0);
-    randomTick->setValue(qs2.toInt());
-    qs2 = qs.section(' ', 1, 1);
-    randomVelocity->setValue(qs2.toInt());
-    qs2 = qs.section(' ', 2, 2);
-    randomLength->setValue(qs2.toInt());
-    qs = arpText.readLine();
-    if (qs == "MIDICC")
-    {
-        qs = arpText.readLine();
-        while (qs != "EOCC") {
-            qs2 = qs.section(' ', 0, 0);
-            int controlID = qs2.toInt();
-            qs2 = qs.section(' ', 1, 1);
-            int ccnumber = qs2.toInt();
-            qs2 = qs.section(' ', 2, 2);
-            int channel = qs2.toInt();
-            qs2 = qs.section(' ', 3, 3);
-            int min = qs2.toInt();
-            qs2 = qs.section(' ', 4, 4);
-            int max = qs2.toInt();
-            midiControl->appendMidiCC(controlID, ccnumber, channel, min, max);
-            qs = arpText.readLine();
-        }
-    qs = arpText.readLine();
-    }
-    if (qs == "Envelope")
-    {
-        qs = arpText.readLine();
-        qs2 = qs.section(' ', 0, 0);
-        attackTime->setValue(qs2.toInt());
-        qs2 = qs.section(' ', 1, 1);
-        releaseTime->setValue(qs2.toInt());
-        qs = arpText.readLine();
-    }
-    while (!arpText.atEnd()) {
-        qs2 = arpText.readLine();
-
-        if (qs2.contains("EOP", Qt::CaseSensitivity(TRUE))) {
-            break;
-        }
-        qs += '\n' + qs2;
-    }
-    patternText->setText(qs);
-    modified = false;
-}
-
 void ArpWidget::setChIn(int value)
 {
     chIn->setCurrentIndex(value);
@@ -920,3 +848,42 @@ void ArpWidget::setModified(bool m)
     modified = m;
     midiControl->setModified(m);
 }
+
+void ArpWidget::handleController(int ccnumber, int channel, int value)
+{
+    bool m;
+    int min, max, sval;
+    QVector<MidiCC> cclist= midiControl->ccList;
+
+    for (int l2 = 0; l2 < cclist.count(); l2++) {
+        min = cclist.at(l2).min;
+        max = cclist.at(l2).max;
+
+        if ((ccnumber == cclist.at(l2).ccnumber) &&
+            (channel == cclist.at(l2).channel)) {
+            switch (cclist.at(l2).ID) {
+                case 0: if (min == max) {
+                            if (value == max) {
+                                m = muteOut->isChecked();
+                                muteOut->setChecked(!m);
+                            }
+                        }
+                        else {
+                            if (value == max) {
+                                muteOut->setChecked(false);
+                            }
+                            if (value == min) {
+                                muteOut->setChecked(true);
+                            }
+                        }
+                break;
+                case 1:
+                        sval = min + ((double)value * (max - min) / 127);
+                        selectPatternPreset(sval);
+                break;
+                default:
+                break;
+            }
+        }
+    }
+}
