@@ -26,15 +26,12 @@
 #include <QLabel>
 #include <QSlider>
 #include <QPushButton>
-#include <QComboBox>
-#include <QSpinBox>
 #include <QStringList>
-#include <QBoxLayout>
 #include <QGroupBox>
-#include <QDateTime>
 
 #include "logwidget.h"
 
+
 LogWidget::LogWidget(QWidget *parent) : QWidget(parent)
 {
     logActive = false;
@@ -74,7 +71,7 @@ LogWidget::~LogWidget()
 {
 }
 
-void LogWidget::appendEvent(MidiEvent ev) {
+void LogWidget::appendEvent(MidiEvent ev, int tick) {
 
     QString qs, qs2;
 
@@ -83,33 +80,33 @@ void LogWidget::appendEvent(MidiEvent ev) {
     }
     switch (ev.type) {
         case EV_NOTEON:
-            qs.sprintf("Ch %2d, Note On %3d, Vel %3d",
+            qs.sprintf("Ch %2d, Note On %3d, Vel %3d, tick %d",
                     ev.channel + 1,
-                    ev.data, ev.value);
+                    ev.data, ev.value, tick);
             break;
         case EV_NOTEOFF:
-            qs.sprintf("Ch %2d, Note Off %3d", ev.channel+1,
-                    ev.data);
+            qs.sprintf("Ch %2d, Note Off %3d, tick %d", ev.channel+1,
+                    ev.data, tick);
             break;
         case EV_CONTROLLER:
             logText->setTextColor(QColor(100,160,0));
-            qs.sprintf("Ch %2d, Ctrl %3d, Val %3d", ev.channel+1,
-                    ev.data, ev.value);
+            qs.sprintf("Ch %2d, Ctrl %3d, Val %3d, tick %d", ev.channel+1,
+                    ev.data, ev.value, tick);
             break;
         case EV_PITCHBEND:
             logText->setTextColor(QColor(100,0,255));
-            qs.sprintf("Ch %2d, Pitch %5d", ev.channel+1,
-                    ev.value);
+            qs.sprintf("Ch %2d, Pitch %5d, tick %d", ev.channel+1,
+                    ev.value, tick);
             break;
         case EV_PGMCHANGE:
             logText->setTextColor(QColor(0,100,100));
-            qs.sprintf("Ch %2d, PrgChg %5d", ev.channel+1,
-                    ev.value);
+            qs.sprintf("Ch %2d, PrgChg %5d, tick %d", ev.channel+1,
+                    ev.value, tick);
             break;
         case EV_CLOCK:
             if (logMidiActive) {
                 logText->setTextColor(QColor(150,150,150));
-                qs = tr("MIDI Clock");
+                qs = tr("MIDI Clock, tick");
             }
             break;
         case EV_START:
