@@ -3,7 +3,7 @@
  *
  *      Handles commandline arguments and options before MainWindow
  *      construction.
- *   @mainpage A MIDI Arpeggiator, LFO and Step Sequencer for ALSA
+ *   @mainpage A MIDI Arpeggiator, LFO and Step Sequencer
  *   @section Description
  *      This attempts to give an overview of the architecture of this
  *      software.
@@ -46,22 +46,34 @@
 static struct option options[] = {
     {"version", 0, 0, 'v'},
     {"help", 0, 0, 'h'},
+    {"alsa", 0, 0, 'a'},
+    {"jack", 0, 0, 'j'},
+    {"jack_session_uuid", required_argument, 0, 'U' },
     {"portCount", 1, 0, 'p'},
     {0, 0, 0, 0}
 };
 
+QString global_jack_session_uuid = "";
+
 int main(int argc, char *argv[])
 {
     int getopt_return;
     int option_index;
     int portCount = 2;
+    bool alsamidi = false;
+    QString s;
+
     QTextStream out(stdout);
 
-    while ((getopt_return = getopt_long(argc, argv, "vhp:", options,
+    while ((getopt_return = getopt_long(argc, argv, "vhajUp:", options,
                     &option_index)) >= 0) {
         switch(getopt_return) {
             case 'v':
-                out << ABOUTMSG;
+                s = QString(ABOUTMSG);
+                s.replace(QString("<br/>"), QString("\n"));
+                s.replace(QString("</p>"), QString("\n"));
+                s.remove(QRegExp("<[^>]*>"));
+                out << s;
                 out.flush();
                 exit(EXIT_SUCCESS);
 
@@ -73,11 +85,25 @@ int main(int argc, char *argv[])
                     "Print application version" << endl;
                 out << "  -h, --help               "
                     "Print this message" << endl;
+                out << "  -a, --alsa               "
+                    "Use ALSA MIDI interface" << endl;
+                out << "  -j, --jack               "
+                    "Use JACK MIDI interface (default)" << endl;
                 out << QString("  -p, --portCount <num>    "
                         "Number of output ports [%1]").arg(portCount) << endl;
                 out.flush();
                 exit(EXIT_SUCCESS);
 
+            case 'a':
+                alsamidi = true;
+                break;
+
+            case 'j':
+                alsamidi = false;
+                break;
+            case 'U':
+                global_jack_session_uuid = QString(optarg);
+                break;
             case 'p':
                 portCount = atoi(optarg);
                 if (portCount > MAX_PORTS)
@@ -106,7 +132,7 @@ int main(int argc, char *argv[])
         app.installTranslator(&qmidiarpTr);
 #endif
 
-    MainWindow* qmidiarp = new MainWindow(portCount);
+    MainWindow* qmidiarp = new MainWindow(portCount, alsamidi);
     if (optind < argc) {
         QFileInfo fi(argv[optind]);
         if (fi.exists())
