@@ -185,7 +185,7 @@ MainWindow::MainWindow(int p_portCount, bool p_alsamidi)
         connect(engine->driver, SIGNAL(j_shutdown()), this,
                 SLOT(jackShutdown()));
     }
-    jackSyncAction->setChecked(!alsaMidi);
+    jackSyncAction->setChecked(false);
     jackSyncAction->setDisabled(true);
 
     updateTransportStatus(false);
@@ -366,8 +366,6 @@ void MainWindow::addArp(const QString& name)
     ArpWidget *moduleWidget = new ArpWidget(midiWorker,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, this);
-    connect(midiWorker, SIGNAL(nextStep(int)),
-            moduleWidget->screen, SLOT(updateScreen(int)));
     connect(moduleWidget, SIGNAL(presetsChanged(const QString&, const
                     QString&, int)),
             this, SLOT(updatePatternPresets(const QString&, const
@@ -403,8 +401,6 @@ void MainWindow::addLfo(const QString& name)
     LfoWidget *moduleWidget = new LfoWidget(midiWorker,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, this);
-    connect(midiWorker, SIGNAL(nextStep(int)),
-            moduleWidget, SLOT(updateScreen(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)),
             this, SLOT(removeLfo(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleClone(int)), this, SLOT(cloneLfo(int)));
@@ -435,16 +431,12 @@ void MainWindow::addSeq(const QString& name)
     SeqWidget *moduleWidget = new SeqWidget(midiWorker,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, this);
-    connect(midiWorker, SIGNAL(nextStep(int)),
-            moduleWidget->screen, SLOT(updateScreen(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)), this, SLOT(removeSeq(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleClone(int)), this, SLOT(cloneSeq(int)));
     connect(moduleWidget->manageBox, SIGNAL(dockRename(const QString&, int)),
             this, SLOT(renameDock(const QString&, int)));
     connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
             engine, SLOT(setMidiLearn(int, int, int)));
-    connect(midiWorker, SIGNAL(noteEvent(int, int)),
-            moduleWidget, SLOT(processNote(int, int)));
 
     widgetID = engine->seqWidgetCount();
     moduleWidget->manageBox->name = name;
@@ -468,8 +460,6 @@ void MainWindow::cloneLfo(int ID)
     LfoWidget *moduleWidget = new LfoWidget(midiWorker,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, this);
-    connect(midiWorker, SIGNAL(nextStep(int)),
-            moduleWidget, SLOT(updateScreen(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)),
             this, SLOT(removeLfo(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleClone(int)), this, SLOT(cloneLfo(int)));
@@ -484,7 +474,7 @@ void MainWindow::cloneLfo(int ID)
     moduleWidget->midiControl->ID = widgetID;
 
     moduleWidget->copyParamsFrom(engine->lfoWidget(ID));
-
+    midiWorker->reverse = engine->lfoWidget(ID)->getReverse();
     midiWorker->setFramePtr(engine->lfoWidget(ID)->getFramePtr());
     midiWorker->nextTick = engine->lfoWidget(ID)->getNextTick();
     engine->addMidiLfo(midiWorker);
@@ -505,16 +495,12 @@ void MainWindow::cloneSeq(int ID)
     SeqWidget *moduleWidget = new SeqWidget(midiWorker,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, this);
-    connect(midiWorker, SIGNAL(nextStep(int)),
-            moduleWidget->screen, SLOT(updateScreen(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleRemove(int)), this, SLOT(removeSeq(int)));
     connect(moduleWidget->manageBox, SIGNAL(moduleClone(int)), this, SLOT(cloneSeq(int)));
     connect(moduleWidget->manageBox, SIGNAL(dockRename(const QString&, int)),
             this, SLOT(renameDock(const QString&, int)));
     connect(moduleWidget->midiControl, SIGNAL(setMidiLearn(int, int, int)),
             engine, SLOT(setMidiLearn(int, int, int)));
-    connect(midiWorker, SIGNAL(noteEvent(int, int)),
-            moduleWidget, SLOT(processNote(int, int)));
 
     widgetID = engine->seqWidgetCount();
     moduleWidget->manageBox->name = engine->seqWidget(ID)->manageBox->name + "_0";
@@ -522,7 +508,7 @@ void MainWindow::cloneSeq(int ID)
     moduleWidget->midiControl->ID = widgetID;
 
     moduleWidget->copyParamsFrom(engine->seqWidget(ID));
-
+    midiWorker->reverse = engine->lfoWidget(ID)->getReverse();
     midiWorker->setCurrentIndex(engine->seqWidget(ID)->getCurrentIndex());
     midiWorker->nextTick = engine->seqWidget(ID)->getNextTick();
     engine->addMidiSeq(midiWorker);
@@ -605,7 +591,7 @@ void MainWindow::removeSeq(int index)
 void MainWindow::clear()
 {
     updateTransportStatus(false);
-    if (alsaMidi) jackSyncToggle(false);
+    jackSyncToggle(false);
 
     while (engine->midiArpCount()) {
         removeArp(engine->midiArpCount() - 1);
@@ -724,7 +710,7 @@ void MainWindow::readFilePartGlobal(QXmlStreamReader& xml)
                     }
                 else if (xml.name() == "jackSyncEnabled") {
                         bool tmp = xml.readElementText().toInt();
-                        if (alsaMidi) jackSyncAction->setChecked(tmp);
+                        jackSyncAction->setChecked(tmp);
                     }
                 else if (xml.name() == "forwardUnmatched")
                     passWidget->setForward(xml.readElementText().toInt());
@@ -1000,7 +986,7 @@ void MainWindow::resetTransport()
 
 void MainWindow::midiClockToggle(bool on)
 {
-    if (on && alsaMidi) jackSyncAction->setChecked(false);
+    if (on) jackSyncAction->setChecked(false);
     engine->setUseMidiClock(on);
     setGUIforExtSync(on);
 }
@@ -1230,17 +1216,15 @@ void MainWindow::checkIfLastModule()
         midiClockAction->setDisabled(true);
         midiClockAction->setChecked(false);
         jackSyncAction->setDisabled(true);
-        if (alsaMidi) jackSyncAction->setChecked(false);
+        jackSyncAction->setChecked(false);
     }
 }
 
 void MainWindow::checkIfFirstModule()
 {
     if (engine->moduleWindowCount() == 1) {
-        if (alsaMidi) {
-            midiClockAction->setEnabled(true);
-            jackSyncAction->setEnabled(true);
-        }
+        if (alsaMidi) midiClockAction->setEnabled(true);
+        jackSyncAction->setEnabled(true);
         runAction->setEnabled(!(midiClockAction->isChecked()
                                 || jackSyncAction->isChecked()));
     }
