@@ -98,6 +98,7 @@ MidiArp::MidiArp()
     gotKbdTrig = false;
     restartFlag = false;
     stepWidth = 1.0;     // stepWidth relative to global queue stepWidth
+    minStepWidth = 1.0;
     len = 0.5;       // note length
     vel = 0.8;  // velocity relative to global velocity
     noteIndex[0] = 0;
@@ -157,7 +158,7 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
     if (inEv.type != EV_NOTEON) return(true);
     if (((inEv.data < indexIn[0]) || (inEv.data > indexIn[1]))
         || ((inEv.value < rangeIn[0]) || (inEv.value > rangeIn[1]))) {
-        return(false);
+        return(true);
     }
 
     if (inEv.value) {
@@ -380,7 +381,7 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
                         octave=0;
                         break;
                     case '>':
-                        stepWidth /= 2.0;
+                        stepWidth *= .5;
                         break;
                     case '<':
                         stepWidth *= 2.0;
@@ -395,10 +396,10 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
                         vel -= 0.2;
                         break;
                     case 'd':
-                        len *= 2;
+                        len *= 2.0;
                         break;
                     case 'h':
-                        len /= 2;
+                        len *= .5;
                         break;
                 }
             }
@@ -406,7 +407,6 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
     } while (advancePatternIndex(false) && (gotCC || chordMode));
 
     l1 = 0;
-
     if (noteCount) do {
         noteIndex[l1] = (noteCount) ? tmpIndex[l1] % noteCount : 0;
         note[l1] = clip(notes[noteBufPtr][0][noteIndex[l1]]
@@ -457,13 +457,19 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
 
     if (!grooveIndex) grooveTick = newGrooveTick;
     grooveTmp = TPQN * stepWidth * grooveTick * 0.01;
-    /** pairwise application of new groove shift */
+    /* pairwise application of new groove shift */
     if (grooveIndex % 2) {
         grooveTmp = -grooveTmp;
         grooveTick = newGrooveTick;
     }
     arpTick += stepWidth * TPQN + grooveTmp;
 
+    if (!trigByKbd && !grooveIndex && !grooveTick) {
+        /* round-up to current resolution (quantize) */
+        arpTick/= (TPQN * minStepWidth);
+        arpTick*= (TPQN * minStepWidth);
+    }
+
     *tick = arpTick + clip(stepWidth * 0.25 * (double)randomTick, 0,
             1000, &outOfRange);
 
@@ -471,7 +477,6 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
         velocity[0] = 0;
     }
     grooveIndex++;
-    emit nextStep(grooveIndex);
 }
 
 bool MidiArp::advancePatternIndex(bool reset)
@@ -515,7 +520,6 @@ void MidiArp::initLoop()
 
 void MidiArp::prepareCurrentNote(int askedTick)
 {
-    newRandomValues();
     gotKbdTrig = false;
     currentTick = askedTick;
     int l1 = 0;
@@ -588,6 +592,8 @@ void MidiArp::updatePattern(const QString& p_pattern)
     pattern = p_pattern;
     patternLen = pattern.length();
     patternMaxIndex = 0;
+    minStepWidth = 1.0;
+
     if (patternLen)
     {
         c = (pattern.at(patternLen - 1));
@@ -605,7 +611,10 @@ void MidiArp::updatePattern(const QString& p_pattern)
         if (c.isDigit() && (c.digitValue() > patternMaxIndex)) {
             patternMaxIndex = c.digitValue();
         }
+        if (c == '>') minStepWidth *= .5;
+        if (c == '<') minStepWidth *= 2.;
     }
+
     patternIndex = 0;
     grooveIndex = 0;
     noteOfs = 0;
