@@ -69,8 +69,9 @@ class MidiLfo : public QObject  {
     int lastMouseLoc;   /*!< The X location of the last modification of the wave, used for interpolation*/
     int lastMouseY;     /*!< The Y location at the last modification of the wave, used for interpolation*/
     int frameptr;       /*!< position of the currently output frame in the MidiArp::data waveform */
-    bool reverse;       /*!< True when the play direction is backwards */
-    bool pingpong;       /*!< True when the play direction alternates */
+    bool backward;       /*!< True when the sequence should start backward */
+    bool pingpong;      /*!< True when the play direction should alternate */
+    bool reflect;      /*!< True when the current play direction will change at the next reflect point */
     int curLoopMode;    /*!< Local storage of the currently active Loop mode */
     int recValue;
     int lastSampleValue;
@@ -104,6 +105,7 @@ class MidiLfo : public QObject  {
     bool enableLoop;
     bool gotKbdTrig;
     bool restartFlag; /*!< Signals frameptr reset on next getNextFrame() call */
+    bool reverse;       /*!< True when the current play direction is backwards */
     int portOut;    /*!< MIDI output port number */
     int channelOut; /*!< MIDI output channel */
     bool recordMode, isRecording;
@@ -252,9 +254,6 @@ class MidiLfo : public QObject  {
     void newGrooveValues(int p_grooveTick, int p_grooveVelocity,
             int p_grooveLength);
     int getFramePtr() { return frameptr;}
-
-  signals:
-    void nextStep(int frameptr);
 };
 
 #endif
