@@ -40,9 +40,12 @@ MidiSeq::MidiSeq()
     seqFinished = false;
     reverse = false;
     pingpong = false;
+    backward = false;
+    reflect = false;
     restartFlag = false;
     curLoopMode = 0;
     noteCount = 0;
+    loopMarker = 0;
 
     nOctaves = 4;
     baseOctave = 3;
@@ -97,7 +100,6 @@ bool MidiSeq::handleEvent(MidiEvent inEv, int tick)
         /*This is a NOTE ON event*/
         if (recordMode) {
             recordNote(inEv.data);
-            emit noteEvent(inEv.data, inEv.value);
             return(false);
         }
         if (enableNoteIn) updateTranspose(inEv.data - 60);
@@ -109,7 +111,6 @@ bool MidiSeq::handleEvent(MidiEvent inEv, int tick)
             nextTick = tick + 2; //schedDelayTicks;
             gotKbdTrig = true;
         }
-        emit noteEvent(inEv.data, inEv.value);
     }
     else {
         /*This is a NOTE OFF event*/
@@ -129,7 +130,6 @@ void MidiSeq::getNextNote(Sample *p_sample, int tick)
     gotKbdTrig = false;
     if (restartFlag) setCurrentIndex(0);
     if (!currentIndex) grooveTick = newGrooveTick;
-    if (!seqFinished) emit nextStep(currentIndex);
 
     sample = customWave.at(currentIndex);
     advancePatternIndex();
@@ -138,7 +138,6 @@ void MidiSeq::getNextNote(Sample *p_sample, int tick)
 
     sample.value+=transp;
     sample.tick = nextTick;
-    if (seqFinished) sample.muted = true;
 
 
     cur_grv_sft = 0.01 * (grooveTick * frame_nticks);
@@ -156,6 +155,10 @@ void MidiSeq::getNextNote(Sample *p_sample, int tick)
         nextTick*=frame_nticks;
     }
 
+    if (seqFinished) {
+        sample.muted = true;
+        currentIndex = 0;
+    }
     *p_sample = sample;
 }
 
@@ -163,21 +166,24 @@ void MidiSeq::advancePatternIndex()
 {
     const int npoints = res * size;
     int pivot = abs(loopMarker);
+    reflect = pingpong;
 
     if (reverse) {
         currentIndex--;
+        if (!pivot) pivot = npoints;
         if (currentIndex == -1) {
-            if (pingpong) {
+            if (!enableLoop) seqFinished = true;
+            if (reflect  || !backward) {
                 reverse = false;
                 currentIndex = 0;
             }
-            else currentIndex = npoints - 1;
+            else currentIndex = pivot - 1;
         }
         else if (currentIndex == pivot - 1) {
             if (!enableLoop) seqFinished = true;
-            if (loopMarker < 0) pingpong = true;
-            if (loopMarker > 0) pingpong = false;
-            if (pingpong) {
+            if (loopMarker < 0) reflect = true;
+            if (loopMarker > 0) reflect = false;
+            if (reflect) {
                 reverse = false;
                 currentIndex = pivot;
             }
@@ -186,19 +192,20 @@ void MidiSeq::advancePatternIndex()
     }
     else {
         currentIndex++;
-        if (!pivot) pivot = npoints;
         if (currentIndex == npoints) {
-            if (pingpong) {
+            if (!enableLoop) seqFinished = true;
+            if (reflect || backward) {
                 reverse = true;
                 currentIndex = npoints - 1;
             }
-            else currentIndex = 0;
+            else currentIndex = pivot;
         }
         else if ((currentIndex == pivot)) {
+            if (!pivot) pivot = npoints;
             if (!enableLoop) seqFinished = true;
-            if (loopMarker > 0) pingpong = true;
-            if (loopMarker < 0) pingpong = false;
-            if (pingpong) {
+            if (loopMarker > 0) reflect = true;
+            if (loopMarker < 0) reflect = false;
+            if (reflect) {
                 reverse = true;
                 currentIndex = pivot - 1;
             }
@@ -255,7 +262,7 @@ void MidiSeq::updateWaveForm(int val)
 
 void MidiSeq::updateLoop(int val)
 {
-    reverse = val&1;
+    backward = val&1;
     pingpong = val&2;
     enableLoop = !(val&4);
     curLoopMode = val;
@@ -381,10 +388,16 @@ void MidiSeq::setCurrentIndex(int ix)
     currentIndex=ix;
 
     if (!ix) {
-        reverse = curLoopMode&1;
         seqFinished = (enableNoteOff && !noteCount);
         restartFlag = false;
-        if (reverse) currentIndex = res * size - 1;
+        if (backward) {
+            reverse = true;
+            if (loopMarker) currentIndex = abs(loopMarker) - 1;
+            else currentIndex = res * size - 1;
+        }
+        else reverse = false;
+
+        reflect = pingpong;
     }
 }
 
