@@ -67,8 +67,9 @@ class MidiSeq : public QObject  {
     double queueTempo;
     int lastMouseLoc;
     int currentIndex;
-    bool reverse;       /*!< True when the play direction is backwards */
-    bool pingpong;      /*!< True when the play direction alternates */
+    bool backward;       /*!< True when the sequence should start backward */
+    bool pingpong;      /*!< True when the play direction should alternate */
+    bool reflect;      /*!< True when the current play direction will change at the next reflect point */
     int curLoopMode;    /*!< Local storage of the currently active Loop mode */
     int noteCount;
     bool recordMode;
@@ -102,6 +103,7 @@ class MidiSeq : public QObject  {
     bool enableLoop;
     bool gotKbdTrig;
     bool restartFlag; /*!< Signals frameptr reset on next getNextFrame() call */
+    bool reverse;       /*!< True when the current play direction is backwards */
     int portOut;        /**< Output port index */
     int channelOut;
     bool isMuted;
@@ -244,10 +246,6 @@ class MidiSeq : public QObject  {
     void setCurrentIndex(int ix);
     int getCurrentIndex() {return currentIndex; }
 
-  signals:
-    void nextStep(int currentIndex);
-    void noteEvent(int note, int velocity);
-
 };
 
 #endif
